@@ -1,3 +1,4 @@
+import re
 import pathlib
 import click
 import yaml
@@ -5,7 +6,7 @@ from bs4 import BeautifulSoup
 from jsonschema import validate
 from jsonschema.exceptions import ValidationError as JSONSchemaValidationError
 
-from .json_schemas import metadata_schema, docker_compose_device_schema
+from .json_schemas import docker_compose_device_schema
 
 
 ERROR_MSG = "Oh no! 💥 💔 💥"
@@ -15,18 +16,8 @@ class ValidationException(Exception):
     pass
 
 
-def __validate_metadata_yml(file_path):
-    with file_path.open("r") as metadata_path:
-        metadata = metadata_path.read()
-        metadata = yaml.load(metadata, Loader=yaml.CLoader)
-
-        try:
-            validate(metadata, metadata_schema)
-        except JSONSchemaValidationError as exc:
-            raise (ValidationException(f"Invalid metadata.yml: {str(exc.message)}"))
-
-
-def __validate_docker_compose_yml(file_path):
+def __validate_docker_compose_yml(path, file):
+    file_path = path / file
     with file_path.open("r") as docker_compose_path:
         docker_compose = docker_compose_path.read()
         docker_compose = yaml.load(docker_compose, Loader=yaml.CLoader)
@@ -42,9 +33,15 @@ def __validate_docker_compose_yml(file_path):
                 )
 
 
-def __validate_english_md(file_path):
+def __validate_english_md(path, file):
+    file_path = path / file
     with file_path.open("r") as content_path:
         content = content_path.read()
+
+        # validate static images
+        for image in re.findall('!\[[^\]]*\]\((.*?)\s*("(?:.*[^"])")?\s*\)', content):
+            assert (path / image[0]).exists(), f"`{image[0]}` not found"
+
         soup = BeautifulSoup(content, "html.parser")
         base_msg = "Invalid english.md:"
 
@@ -125,18 +122,17 @@ def __validate_english_md(file_path):
         ), f"{base_msg} Duplicated activity ids"
 
 
-def validate_file_format(file_path):
+def validate_file_format(path, file):
     mapping = {
-        "metadata.yml": __validate_metadata_yml,
         "docker-compose.yml": __validate_docker_compose_yml,
         "english.md": __validate_english_md,
     }
-    validator_callable = mapping[file_path.name]
-    validator_callable(file_path)
+    validator_callable = mapping[file]
+    validator_callable(path, file)
 
 
 @click.group()
-@click.version_option("0.2.0")
+@click.version_option("0.4.0")
 def content_tools():
     pass
 
@@ -150,7 +146,7 @@ def validate_module_repo(path):
     assert path.is_dir(), "Required a directory path"
 
     # check required files
-    for file in ("metadata.yml", "docker-compose.yml", "english.md"):
+    for file in ("docker-compose.yml", "english.md"):
         try:
             assert (path / file).exists(), f"`{file}` not found"
         except AssertionError as exc:
@@ -161,7 +157,7 @@ def validate_module_repo(path):
             click.echo(f"✅ {file} exists")
 
         try:
-            validate_file_format(path / file)
+            validate_file_format(path, file)
         except (ValidationException, AssertionError) as exc:
             click.echo(f"❌ {file} has a valid format")
             click.echo(f"\n{ERROR_MSG} \n{str(exc)}")
